# Description

Please note that this is a dummy resource environment, as the mini swe agent needs to be run under a different response_api_agents, and the implementations and instructions can be found at https://github.com/NVIDIA-NeMo/Gym/tree/main/responses_api_agents/mini_swe_agent.